@@ -462,9 +462,10 @@ class IQ_Option:
             while self.check_connect:
                 if self.api.candles.candles_data != None:
                     break
-        except:
-            logging.error('**error** get_candles need reconnect')
-            raise ConnectionError
+        except Exception as e:
+            logging.error('**error** get_candles need reconnect: ')
+            logging.error(e)
+            raise ConnectionError()
 
         return self.api.candles.candles_data
 
